# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from sullyai import SullyAI, AsyncSullyAI
from tests.utils import assert_matches_type
from sullyai.types import DeleteResponse, NoteCreateResponse, NoteRetrieveResponse
from sullyai._utils import parse_date

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestNotes:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: SullyAI) -> None:
        note = client.notes.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        )
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: SullyAI) -> None:
        note = client.notes.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
            context="context",
            instructions=[
                "Use a professional and concise tone.",
                "Include key details without unnecessary elaboration.",
                "Ensure clarity for a general audience.",
            ],
            language="en",
            medication_list="medicationList",
            note_type={
                "description": "description",
                "include_json": True,
                "template": "write a standard clinical SOAP note with the following sections: - **Subjective**: Contains detailed HPI. - **Objective**: Contains PE and ROS. - **Assessment**: Contains differential diagnoses with corresponding plans. - **Patient Instructions**: Contains a list of instructions for the patient.",
                "type": "note_style",
            },
            patient_info={
                "date_of_birth": parse_date("2019-12-27"),
                "gender": "male",
                "name": "name",
            },
            previous_note="previousNote",
        )
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: SullyAI) -> None:
        response = client.notes.with_raw_response.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = response.parse()
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: SullyAI) -> None:
        with client.notes.with_streaming_response.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = response.parse()
            assert_matches_type(NoteCreateResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: SullyAI) -> None:
        note = client.notes.retrieve(
            "noteId",
        )
        assert_matches_type(NoteRetrieveResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: SullyAI) -> None:
        response = client.notes.with_raw_response.retrieve(
            "noteId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = response.parse()
        assert_matches_type(NoteRetrieveResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: SullyAI) -> None:
        with client.notes.with_streaming_response.retrieve(
            "noteId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = response.parse()
            assert_matches_type(NoteRetrieveResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: SullyAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `note_id` but received ''"):
            client.notes.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: SullyAI) -> None:
        note = client.notes.delete(
            "noteId",
        )
        assert_matches_type(DeleteResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: SullyAI) -> None:
        response = client.notes.with_raw_response.delete(
            "noteId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = response.parse()
        assert_matches_type(DeleteResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: SullyAI) -> None:
        with client.notes.with_streaming_response.delete(
            "noteId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = response.parse()
            assert_matches_type(DeleteResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_delete(self, client: SullyAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `note_id` but received ''"):
            client.notes.with_raw_response.delete(
                "",
            )


class TestAsyncNotes:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncSullyAI) -> None:
        note = await async_client.notes.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        )
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncSullyAI) -> None:
        note = await async_client.notes.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
            context="context",
            instructions=[
                "Use a professional and concise tone.",
                "Include key details without unnecessary elaboration.",
                "Ensure clarity for a general audience.",
            ],
            language="en",
            medication_list="medicationList",
            note_type={
                "description": "description",
                "include_json": True,
                "template": "write a standard clinical SOAP note with the following sections: - **Subjective**: Contains detailed HPI. - **Objective**: Contains PE and ROS. - **Assessment**: Contains differential diagnoses with corresponding plans. - **Patient Instructions**: Contains a list of instructions for the patient.",
                "type": "note_style",
            },
            patient_info={
                "date_of_birth": parse_date("2019-12-27"),
                "gender": "male",
                "name": "name",
            },
            previous_note="previousNote",
        )
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncSullyAI) -> None:
        response = await async_client.notes.with_raw_response.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = await response.parse()
        assert_matches_type(NoteCreateResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncSullyAI) -> None:
        async with async_client.notes.with_streaming_response.create(
            date=parse_date("2019-12-27"),
            transcript="Hey, how's it going? Good good yeah, so what's going on? Yeah, hi I'm Edward yeah hi hi Edward. How's it going? Yeah, good good. So I've been having a couple of issues like my back pain and knee pain.",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = await response.parse()
            assert_matches_type(NoteCreateResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSullyAI) -> None:
        note = await async_client.notes.retrieve(
            "noteId",
        )
        assert_matches_type(NoteRetrieveResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSullyAI) -> None:
        response = await async_client.notes.with_raw_response.retrieve(
            "noteId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = await response.parse()
        assert_matches_type(NoteRetrieveResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSullyAI) -> None:
        async with async_client.notes.with_streaming_response.retrieve(
            "noteId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = await response.parse()
            assert_matches_type(NoteRetrieveResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSullyAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `note_id` but received ''"):
            await async_client.notes.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncSullyAI) -> None:
        note = await async_client.notes.delete(
            "noteId",
        )
        assert_matches_type(DeleteResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSullyAI) -> None:
        response = await async_client.notes.with_raw_response.delete(
            "noteId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        note = await response.parse()
        assert_matches_type(DeleteResponse, note, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSullyAI) -> None:
        async with async_client.notes.with_streaming_response.delete(
            "noteId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            note = await response.parse()
            assert_matches_type(DeleteResponse, note, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSullyAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `note_id` but received ''"):
            await async_client.notes.with_raw_response.delete(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["TranscriptionCreateResponse", "Data"]


class Data(BaseModel):
    message: Optional[str] = None
    """Informational message about the request status."""

    status: Optional[str] = None
    """The processing status of the transcription request. Always 'pending'."""

    transcription_id: Optional[str] = FieldInfo(alias="transcriptionId", default=None)
    """Unique identifier for the audio transcription request."""


class TranscriptionCreateResponse(BaseModel):
    data: Optional[Data] = None

    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import TYPE_CHECKING, List, Union, Optional
from typing_extensions import Literal, TypeAlias, TypeAliasType

from pydantic import Field as FieldInfo

from ..._compat import PYDANTIC_V2
from ..._models import BaseModel

__all__ = ["Section", "UnionMember1", "UnionMember1Properties", "UnionMember2", "UnionMember2Properties"]


class UnionMember1Properties(BaseModel):
    bold: Optional[bool] = None
    """Whether the text should be bold."""

    detail_level: Optional[Literal["exhaustive", "detailed", "standard", "brief", "minimal"]] = None
    """Determines the level of detail in the text content."""

    empty_placeholder: Optional[str] = FieldInfo(alias="emptyPlaceholder", default=None)
    """Placeholder text to display if content is empty."""

    formatting_style: Optional[Literal["markdown", "plain"]] = None
    """Specifies the formatting style of the text."""

    hide_if_empty: Optional[bool] = FieldInfo(alias="hideIfEmpty", default=None)
    """Whether to hide the content if it's empty."""

    italic: Optional[bool] = None
    """Whether the text should be italicized."""

    tone: Optional[Literal["formal", "casual", "technical", "friendly", "instructional"]] = None
    """Defines the tone of the generated text."""


class UnionMember1(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the section."""

    bold_label: Optional[bool] = None
    """Whether the label should be bold."""

    italic_label: Optional[bool] = None
    """Whether the label should be italicized."""

    label: Optional[str] = None
    """An optional label for the text section."""

    list_type: Optional[Literal["bullet", "numeric"]] = None
    """Defines whether text should be formatted as a bullet or numeric list."""

    max_paragraphs: Optional[int] = None
    """Maximum number of paragraphs allowed."""

    max_sentences: Optional[int] = None
    """Maximum number of sentences allowed."""

    min_paragraphs: Optional[int] = None
    """Minimum number of paragraphs required."""

    min_sentences: Optional[int] = None
    """Minimum number of sentences required."""

    properties: Optional[UnionMember1Properties] = None
    """Common properties for text-based content."""

    result: Optional[str] = None
    """The generated text content."""

    type: Optional[Literal["text", "heading", "list"]] = None


class UnionMember2Properties(BaseModel):
    bold: Optional[bool] = None
    """Whether the text should be bold."""

    detail_level: Optional[Literal["exhaustive", "detailed", "standard", "brief", "minimal"]] = None
    """Determines the level of detail in the text content."""

    empty_placeholder: Optional[str] = FieldInfo(alias="emptyPlaceholder", default=None)
    """Placeholder text to display if content is empty."""

    formatting_style: Optional[Literal["markdown", "plain"]] = None
    """Specifies the formatting style of the text."""

    hide_if_empty: Optional[bool] = FieldInfo(alias="hideIfEmpty", default=None)
    """Whether to hide the content if it's empty."""

    italic: Optional[bool] = None
    """Whether the text should be italicized."""

    tone: Optional[Literal["formal", "casual", "technical", "friendly", "instructional"]] = None
    """Defines the tone of the generated text."""


class UnionMember2(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the section."""

    list_type: Optional[Literal["bullet", "numeric"]] = None
    """Defines whether the list is bulleted or numbered."""

    max_items: Optional[int] = None
    """Maximum number of items allowed in the list."""

    min_items: Optional[int] = None
    """Minimum number of items required in the list."""

    properties: Optional[UnionMember2Properties] = None
    """Common properties for text-based content."""

    result: Optional[List[str]] = None
    """The generated list items."""

    type: Optional[Literal["list", "heading", "text"]] = None


if TYPE_CHECKING or PYDANTIC_V2:
    Section = TypeAliasType("Section", Union["HeadingSection", UnionMember1, UnionMember2])
else:
    Section: TypeAlias = Union["HeadingSection", UnionMember1, UnionMember2]

from .heading_section import HeadingSection

if PYDANTIC_V2:
    UnionMember1.model_rebuild()
    UnionMember1Properties.model_rebuild()
    UnionMember2.model_rebuild()
    UnionMember2Properties.model_rebuild()
else:
    UnionMember1.update_forward_refs()  # type: ignore
    UnionMember1Properties.update_forward_refs()  # type: ignore
    UnionMember2.update_forward_refs()  # type: ignore
    UnionMember2Properties.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .stream_create_token_params import StreamCreateTokenParams as StreamCreateTokenParams
from .stream_create_token_response import StreamCreateTokenResponse as StreamCreateTokenResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, cast

import httpx

from .stream import (
    StreamResource,
    AsyncStreamResource,
    StreamResourceWithRawResponse,
    AsyncStreamResourceWithRawResponse,
    StreamResourceWithStreamingResponse,
    AsyncStreamResourceWithStreamingResponse,
)
from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven, FileTypes
from ...._utils import extract_files, maybe_transform, deepcopy_minimal, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....types.audio import transcription_create_params
from ...._base_client import make_request_options
from ....types.delete_response import DeleteResponse
from ....types.audio.transcription_create_response import TranscriptionCreateResponse
from ....types.audio.transcription_retrieve_response import TranscriptionRetrieveResponse

__all__ = ["TranscriptionsResource", "AsyncTranscriptionsResource"]


class TranscriptionsResource(SyncAPIResource):
    @cached_property
    def stream(self) -> StreamResource:
        return StreamResource(self._client)

    @cached_property
    def with_raw_response(self) -> TranscriptionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return TranscriptionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TranscriptionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return TranscriptionsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        audio: FileTypes,
        language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TranscriptionCreateResponse:
        """
        Creates a new audio transcription

        Args:
          audio: Audio file to transcribe (supported formats: wav, mp3, m4a, ogg)

          language:
              Language code for transcription:

              - English (en-US, en-GB) - Spanish (es) - French (fr) - German (de) - Italian
                (it) - Portuguese (pt) - Dutch (nl) - Japanese (ja) - Korean (ko) - Chinese
                (zh) - Russian (ru)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal(
            {
                "audio": audio,
                "language": language,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["audio"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/v1/audio/transcriptions",
            body=maybe_transform(body, transcription_create_params.TranscriptionCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionCreateResponse,
        )

    def retrieve(
        self,
        transcription_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TranscriptionRetrieveResponse:
        """
        Gets a single audio transcription based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not transcription_id:
            raise ValueError(f"Expected a non-empty value for `transcription_id` but received {transcription_id!r}")
        return self._get(
            f"/v1/audio/transcriptions/{transcription_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionRetrieveResponse,
        )

    def delete(
        self,
        transcription_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DeleteResponse:
        """
        Deletes a single audio transcription based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not transcription_id:
            raise ValueError(f"Expected a non-empty value for `transcription_id` but received {transcription_id!r}")
        return self._delete(
            f"/v1/audio/transcriptions/{transcription_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DeleteResponse,
        )


class AsyncTranscriptionsResource(AsyncAPIResource):
    @cached_property
    def stream(self) -> AsyncStreamResource:
        return AsyncStreamResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncTranscriptionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTranscriptionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTranscriptionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return AsyncTranscriptionsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        audio: FileTypes,
        language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TranscriptionCreateResponse:
        """
        Creates a new audio transcription

        Args:
          audio: Audio file to transcribe (supported formats: wav, mp3, m4a, ogg)

          language:
              Language code for transcription:

              - English (en-US, en-GB) - Spanish (es) - French (fr) - German (de) - Italian
                (it) - Portuguese (pt) - Dutch (nl) - Japanese (ja) - Korean (ko) - Chinese
                (zh) - Russian (ru)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal(
            {
                "audio": audio,
                "language": language,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["audio"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/v1/audio/transcriptions",
            body=await async_maybe_transform(body, transcription_create_params.TranscriptionCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionCreateResponse,
        )

    async def retrieve(
        self,
        transcription_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TranscriptionRetrieveResponse:
        """
        Gets a single audio transcription based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not transcription_id:
            raise ValueError(f"Expected a non-empty value for `transcription_id` but received {transcription_id!r}")
        return await self._get(
            f"/v1/audio/transcriptions/{transcription_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TranscriptionRetrieveResponse,
        )

    async def delete(
        self,
        transcription_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DeleteResponse:
        """
        Deletes a single audio transcription based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not transcription_id:
            raise ValueError(f"Expected a non-empty value for `transcription_id` but received {transcription_id!r}")
        return await self._delete(
            f"/v1/audio/transcriptions/{transcription_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DeleteResponse,
        )


class TranscriptionsResourceWithRawResponse:
    def __init__(self, transcriptions: TranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = to_raw_response_wrapper(
            transcriptions.create,
        )
        self.retrieve = to_raw_response_wrapper(
            transcriptions.retrieve,
        )
        self.delete = to_raw_response_wrapper(
            transcriptions.delete,
        )

    @cached_property
    def stream(self) -> StreamResourceWithRawResponse:
        return StreamResourceWithRawResponse(self._transcriptions.stream)


class AsyncTranscriptionsResourceWithRawResponse:
    def __init__(self, transcriptions: AsyncTranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = async_to_raw_response_wrapper(
            transcriptions.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            transcriptions.retrieve,
        )
        self.delete = async_to_raw_response_wrapper(
            transcriptions.delete,
        )

    @cached_property
    def stream(self) -> AsyncStreamResourceWithRawResponse:
        return AsyncStreamResourceWithRawResponse(self._transcriptions.stream)


class TranscriptionsResourceWithStreamingResponse:
    def __init__(self, transcriptions: TranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = to_streamed_response_wrapper(
            transcriptions.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            transcriptions.retrieve,
        )
        self.delete = to_streamed_response_wrapper(
            transcriptions.delete,
        )

    @cached_property
    def stream(self) -> StreamResourceWithStreamingResponse:
        return StreamResourceWithStreamingResponse(self._transcriptions.stream)


class AsyncTranscriptionsResourceWithStreamingResponse:
    def __init__(self, transcriptions: AsyncTranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = async_to_streamed_response_wrapper(
            transcriptions.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            transcriptions.retrieve,
        )
        self.delete = async_to_streamed_response_wrapper(
            transcriptions.delete,
        )

    @cached_property
    def stream(self) -> AsyncStreamResourceWithStreamingResponse:
        return AsyncStreamResourceWithStreamingResponse(self._transcriptions.stream)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal

from ..._compat import PYDANTIC_V2
from ..._models import BaseModel

__all__ = ["HeadingSection"]


class HeadingSection(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the section."""

    children: Optional[List["Section"]] = None
    """Nested sections under the heading."""

    level: Optional[int] = None
    """Specifies the heading level (e.g., H1 to H6)."""

    text: Optional[str] = None
    """The actual text of the heading."""

    type: Optional[Literal["heading", "text", "list"]] = None


from .section import Section

if PYDANTIC_V2:
    HeadingSection.model_rebuild()
else:
    HeadingSection.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["NoteCreateResponse", "Data"]


class Data(BaseModel):
    note_id: Optional[str] = FieldInfo(alias="noteId", default=None)
    """Unique identifier for the created note"""


class NoteCreateResponse(BaseModel):
    data: Optional[Data] = None

    date: Optional[datetime] = None
    """Timestamp of the response"""

    status: Optional[str] = None
    """Status of the response"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["StreamCreateTokenParams"]


class StreamCreateTokenParams(TypedDict, total=False):
    expires_in: Required[Annotated[int, PropertyInfo(alias="expiresIn")]]
    """Duration of the token in seconds"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from sullyai import SullyAI, AsyncSullyAI
from tests.utils import assert_matches_type
from sullyai.types.audio.transcriptions import StreamCreateTokenResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestStream:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_token(self, client: SullyAI) -> None:
        stream = client.audio.transcriptions.stream.create_token(
            expires_in=3600,
        )
        assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_token(self, client: SullyAI) -> None:
        response = client.audio.transcriptions.stream.with_raw_response.create_token(
            expires_in=3600,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        stream = response.parse()
        assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_token(self, client: SullyAI) -> None:
        with client.audio.transcriptions.stream.with_streaming_response.create_token(
            expires_in=3600,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            stream = response.parse()
            assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncStream:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_token(self, async_client: AsyncSullyAI) -> None:
        stream = await async_client.audio.transcriptions.stream.create_token(
            expires_in=3600,
        )
        assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_token(self, async_client: AsyncSullyAI) -> None:
        response = await async_client.audio.transcriptions.stream.with_raw_response.create_token(
            expires_in=3600,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        stream = await response.parse()
        assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_token(self, async_client: AsyncSullyAI) -> None:
        async with async_client.audio.transcriptions.stream.with_streaming_response.create_token(
            expires_in=3600,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            stream = await response.parse()
            assert_matches_type(StreamCreateTokenResponse, stream, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .audio import (
    AudioResource,
    AsyncAudioResource,
    AudioResourceWithRawResponse,
    AsyncAudioResourceWithRawResponse,
    AudioResourceWithStreamingResponse,
    AsyncAudioResourceWithStreamingResponse,
)
from .notes import (
    NotesResource,
    AsyncNotesResource,
    NotesResourceWithRawResponse,
    AsyncNotesResourceWithRawResponse,
    NotesResourceWithStreamingResponse,
    AsyncNotesResourceWithStreamingResponse,
)
from .note_styles import (
    NoteStylesResource,
    AsyncNoteStylesResource,
    NoteStylesResourceWithRawResponse,
    AsyncNoteStylesResourceWithRawResponse,
    NoteStylesResourceWithStreamingResponse,
    AsyncNoteStylesResourceWithStreamingResponse,
)

__all__ = [
    "NotesResource",
    "AsyncNotesResource",
    "NotesResourceWithRawResponse",
    "AsyncNotesResourceWithRawResponse",
    "NotesResourceWithStreamingResponse",
    "AsyncNotesResourceWithStreamingResponse",
    "NoteStylesResource",
    "AsyncNoteStylesResource",
    "NoteStylesResourceWithRawResponse",
    "AsyncNoteStylesResourceWithRawResponse",
    "NoteStylesResourceWithStreamingResponse",
    "AsyncNoteStylesResourceWithStreamingResponse",
    "AudioResource",
    "AsyncAudioResource",
    "AudioResourceWithRawResponse",
    "AsyncAudioResourceWithRawResponse",
    "AudioResourceWithStreamingResponse",
    "AsyncAudioResourceWithStreamingResponse",
]
